#pragma once

#include "pt2-clone.h"

module_t * get_mod(SEXP mod);
